package de.intevation.flys.artifacts.model;

import de.intevation.flys.artifacts.math.Linear;

import java.util.Arrays;

import java.io.Serializable;

public class FixingsColumn
implements   Serializable
{
    protected int columnId;

    protected double [] kms;
    protected double [] ws;

    protected QRangeTree qs;

    public FixingsColumn() {
    }

    public FixingsColumn(
        int       columnId, 
        double [] kms,
        double [] ws
    ) {
        this.columnId = columnId;
        this.kms      = kms;
        this.ws       = ws;
    }

    public int getColumnId() {
        return columnId;
    }

    public boolean getW(double km, double [] w) {

        if (km < kms[0] || km > kms[kms.length-1]) {
            w[0] = Double.NaN;
            return true;
        }

        int idx = Arrays.binarySearch(kms, km);

        if (idx >= 0) {
            w[0] = ws[idx];
            return true;
        }

        idx = -idx - 1;

        w[0] = Linear.linear(km, kms[idx], kms[idx+1], ws[idx], ws[idx+1]);
        return false;
    }

    public double getQ(double km) {
        return qs.findQ(km);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
